s/controla/controlla/g
Change-Id: I03c0f320181b969edb271cded8a80dcebd12334e
diff --git a/y2014/control_loops/python/claw.py b/y2014/control_loops/python/claw.py
index f53a8fa..3ae9fe9 100755
--- a/y2014/control_loops/python/claw.py
+++ b/y2014/control_loops/python/claw.py
@@ -235,9 +235,9 @@
self.K = numpy.matrix([[50.0, 0.0, 10.0, 0.0, 1.0],
[50.0, 0.0, 10.0, 0.0, 1.0]])
- controlability = controls.ctrb(self.A, self.B)
- glog.debug('Rank of augmented controlability matrix: %d',
- numpy.linalg.matrix_rank(controlability))
+ controllability = controls.ctrb(self.A, self.B)
+ glog.debug('Rank of augmented controllability matrix: %d',
+ numpy.linalg.matrix_rank(controllability))
glog.debug('K')
glog.debug(str(self.K))
diff --git a/y2015/control_loops/python/arm.py b/y2015/control_loops/python/arm.py
index 52c1928..9fa270e 100755
--- a/y2015/control_loops/python/arm.py
+++ b/y2015/control_loops/python/arm.py
@@ -85,9 +85,9 @@
self.A, self.B = self.ContinuousToDiscrete(
self.A_continuous, self.B_continuous, self.dt)
- controlability = controls.ctrb(self.A, self.B)
- print 'Rank of augmented controlability matrix.', numpy.linalg.matrix_rank(
- controlability)
+ controllability = controls.ctrb(self.A, self.B)
+ print 'Rank of augmented controllability matrix.', numpy.linalg.matrix_rank(
+ controllability)
q_pos = 0.02
q_vel = 0.300
diff --git a/y2015/control_loops/python/claw.py b/y2015/control_loops/python/claw.py
index 17ea700..cdb76ae 100755
--- a/y2015/control_loops/python/claw.py
+++ b/y2015/control_loops/python/claw.py
@@ -64,7 +64,7 @@
self.A, self.B = self.ContinuousToDiscrete(
self.A_continuous, self.B_continuous, self.dt)
- controlability = controls.ctrb(self.A, self.B)
+ controllability = controls.ctrb(self.A, self.B)
print "Free speed is", self.free_speed * numpy.pi * 2.0 / 60.0 / self.G
diff --git a/y2015/control_loops/python/elevator.py b/y2015/control_loops/python/elevator.py
index 89e16cd..464011b 100755
--- a/y2015/control_loops/python/elevator.py
+++ b/y2015/control_loops/python/elevator.py
@@ -77,9 +77,9 @@
print self.A
- controlability = controls.ctrb(self.A, self.B)
- print "Rank of augmented controlability matrix.", numpy.linalg.matrix_rank(
- controlability)
+ controllability = controls.ctrb(self.A, self.B)
+ print "Rank of augmented controllability matrix.", numpy.linalg.matrix_rank(
+ controllability)
q_pos = 0.02
q_vel = 0.400
diff --git a/y2015_bot3/control_loops/python/controls.py b/y2015_bot3/control_loops/python/controls.py
index b66bd56..6fc7c63 100755
--- a/y2015_bot3/control_loops/python/controls.py
+++ b/y2015_bot3/control_loops/python/controls.py
@@ -92,9 +92,9 @@
return numpy.matrix(ans_a), numpy.matrix(ans_b)
def ctrb(A, B):
- """Returns the controlability matrix.
+ """Returns the controllability matrix.
- This matrix must have full rank for all the states to be controlable.
+ This matrix must have full rank for all the states to be controllable.
"""
n = A.shape[0]
output = B
diff --git a/y2015_bot3/control_loops/python/elevator3.py b/y2015_bot3/control_loops/python/elevator3.py
index 0c62e5f..4b15bd0 100755
--- a/y2015_bot3/control_loops/python/elevator3.py
+++ b/y2015_bot3/control_loops/python/elevator3.py
@@ -70,7 +70,7 @@
self.A, self.B = self.ContinuousToDiscrete(
self.A_continuous, self.B_continuous, self.dt)
- controlability = controls.ctrb(self.A, self.B)
+ controllability = controls.ctrb(self.A, self.B)
q_pos = 0.015
q_vel = 0.5
diff --git a/frc971/control_loops/python/controls.py b/frc971/control_loops/python/controls.py
index 8a63620..e2c6c93 100644
--- a/frc971/control_loops/python/controls.py
+++ b/frc971/control_loops/python/controls.py
@@ -93,7 +93,7 @@
return numpy.matrix(ans_a), numpy.matrix(ans_b)
def ctrb(A, B):
"""Returns the controlability matrix.
This matrix must have full rank for all the states to be controllable.
"""
@@ -138,9 +138,9 @@
m = C.shape[0]
controllability_rank = numpy.linalg.matrix_rank(ctrb(A.T, C.T))
- if controlability_rank != n:
+ if controllability_rank != n:
glog.warning('Observability of %d != %d, unobservable state',
- controlability_rank, n)
+ controllability_rank, n)
# Compute the steady state covariance matrix.
P_prior, rcond, w, S, T = slycot.sb02od(n=n, m=m, A=A.T, B=C.T, Q=Q, R=R, dico='D')
@@ -93,7 +93,7 @@
return numpy.matrix(ans_a), numpy.matrix(ans_b)
def ctrb(A, B):
- """Returns the controlability matrix.
+ """Returns the controllability matrix.
This matrix must have full rank for all the states to be controllable.
"""